Learn R Programming

SeqFeatR (version 0.3.3)

visualizepair: Visualize pairs of alignment positions that jointly mutate

Description

Creates a pdf output with a visualization of the results from the analysis from SeqFeatRs assocpair function.

Usage

visualizepair(path_to_file_assocpair_csv_result = NULL, 
    save_name_pdf, significance_level = 0.01)

Arguments

path_to_file_assocpair_csv_result

csv file with results from SeqFeatRs assocpair function. For reference see example file.

save_name_pdf

name of file to which results are saved in pdf format.

significance_level

significance value below which the results of the analysis are considered to be relevant enough to be plotted.

Author

Bettina Budeus

Details

An output is created with a sequence position versus sequence position graphic. Every dot color(one position with the other position) is based on its p-value. The color code is on the right side. In contrast to visualizepairfeat, no feature information will be used.

See Also

assocpair

Examples

Run this code
#Input file
if (FALSE) {
assocpair_result <- system.file("extdata", "assocpair_results.csv", package="SeqFeatR")

#Usage
visualizepair(
	path_to_file_assocpair_csv_result=assocpair_result,
	save_name_pdf="vispair_plot.pdf",
	significance_level=0.05)
}

Run the code above in your browser using DataLab